@@ -1380,7 +1380,7 @@ e_contact_duplicate (EContact *contact)
 const gchar *
 e_contact_field_name (EContactField field_id)
 {
-	g_return_val_if_fail (field_id >= 1 && field_id <= E_CONTACT_FIELD_LAST, "");
+	g_return_val_if_fail (field_id >= 1 && field_id < E_CONTACT_FIELD_LAST, "");
 
 	return field_info[field_id].field_name;
 }
@@ -1397,7 +1397,7 @@ e_contact_field_name (EContactField field_id)
 const gchar *
 e_contact_pretty_name (EContactField field_id)
 {
-	g_return_val_if_fail (field_id >= 1 && field_id <= E_CONTACT_FIELD_LAST, "");
+	g_return_val_if_fail (field_id >= 1 && field_id < E_CONTACT_FIELD_LAST, "");
 
 #ifdef ENABLE_NLS
 	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
@@ -1418,7 +1418,7 @@ e_contact_pretty_name (EContactField field_id)
 const gchar *
 e_contact_vcard_attribute (EContactField field_id)
 {
-	g_return_val_if_fail (field_id >= 1 && field_id <= E_CONTACT_FIELD_LAST, "");
+	g_return_val_if_fail (field_id >= 1 && field_id < E_CONTACT_FIELD_LAST, "");
 
 	return field_info[field_id].vcard_field_name;
 }
@@ -1487,7 +1487,7 @@ e_contact_get (EContact *contact,
 	const EContactFieldInfo *info = NULL;
 
 	g_return_val_if_fail (contact && E_IS_CONTACT (contact), NULL);
-	g_return_val_if_fail (field_id >= 1 && field_id <= E_CONTACT_FIELD_LAST, NULL);
+	g_return_val_if_fail (field_id >= 1 && field_id < E_CONTACT_FIELD_LAST, NULL);
 
 	info = &field_info[field_id];
 
@@ -1689,6 +1689,7 @@ e_contact_get_const (EContact *contact,
 	gpointer value = NULL;
 
 	g_return_val_if_fail (E_IS_CONTACT (contact), NULL);
+	g_return_val_if_fail (field_id >= 1 && field_id < E_CONTACT_FIELD_LAST, NULL);
 	g_return_val_if_fail (field_info[field_id].t & E_CONTACT_FIELD_TYPE_STRING, NULL);
 
 	value = contact->priv->cached_strings[field_id];
@@ -1718,7 +1719,7 @@ e_contact_set (EContact *contact,
 	d(printf ("e_contact_set (%p, %d, %p)\n", contact, field_id, value));
 
 	g_return_if_fail (contact && E_IS_CONTACT (contact));
-	g_return_if_fail (field_id >= 1 && field_id <= E_CONTACT_FIELD_LAST);
+	g_return_if_fail (field_id >= 1 && field_id < E_CONTACT_FIELD_LAST);
 
 	/* set the cached slot to NULL so we'll re-get the new string
 	 * if e_contact_get_const is called again */
@@ -1748,7 +1749,7 @@ e_contact_get_attributes (EContact *contact,
 	const EContactFieldInfo *info = NULL;
 
 	g_return_val_if_fail (contact && E_IS_CONTACT (contact), NULL);
-	g_return_val_if_fail (field_id >= 1 && field_id <= E_CONTACT_FIELD_LAST, NULL);
+	g_return_val_if_fail (field_id >= 1 && field_id < E_CONTACT_FIELD_LAST, NULL);
 
 	info = &field_info[field_id];
 
@@ -1786,7 +1787,7 @@ e_contact_set_attributes (EContact *contact,
 	GList *l;
 
 	g_return_if_fail (contact && E_IS_CONTACT (contact));
-	g_return_if_fail (field_id >= 1 && field_id <= E_CONTACT_FIELD_LAST);
+	g_return_if_fail (field_id >= 1 && field_id < E_CONTACT_FIELD_LAST);
 
 	info = &field_info[field_id];
 
@@ -1856,7 +1857,7 @@ e_contact_name_from_string (const gchar *name_str)
 	g_return_val_if_fail (name_str != NULL, NULL);
 
 	name = e_contact_name_new ();
-	western = e_name_western_parse (name_str ? name_str : "");
+	western = e_name_western_parse (name_str);
 
 	name->prefixes   = g_strdup (western->prefix);
 	name->given      = g_strdup (western->first );
