@@ -32,7 +32,7 @@ void
 string_to_dbt (const gchar *str,
                DBT *dbt)
 {
-	memset (dbt, 0, sizeof (dbt));
+	memset (dbt, 0, sizeof (DBT));
 	dbt->data = (gpointer) str;
 	dbt->size = strlen (str) + 1;
 	dbt->flags = DB_DBT_USERMEM;
@@ -144,7 +144,7 @@ e_book_backend_db_cache_get_contact (DB *db,
 		return NULL;
 	}
 
-	contact = e_contact_new_from_vcard ((const gchar *) vcard_dbt.data);
+	contact = e_contact_new_from_vcard_with_uid ((const gchar *) vcard_dbt.data, uid);
 	g_free (vcard_dbt.data);
 	return contact;
 }
@@ -299,7 +299,7 @@ e_book_backend_db_cache_get_contacts (DB *db,
 		if (vcard_dbt.data && !strncmp (vcard_dbt.data, "BEGIN:VCARD", 11)) {
 			contact = e_contact_new_from_vcard (vcard_dbt.data);
 
-			if (e_book_backend_sexp_match_contact (sexp, contact))
+			if (!sexp || e_book_backend_sexp_match_contact (sexp, contact))
 				list = g_list_prepend (list, contact);
 			else
 				g_object_unref (contact);
@@ -319,7 +319,7 @@ e_book_backend_db_cache_get_contacts (DB *db,
 
 /**
  * e_book_backend_db_cache_search:
- * @backend: an #EBookBackend
+ * @db: DB handle
  * @query: an s-expression
  *
  * Returns an array of pointers to unique contact ID strings for contacts
@@ -373,7 +373,7 @@ e_book_backend_db_cache_exists (const gchar *uri)
 
 /**
  * e_book_backend_db_cache_set_populated:
- * @backend: an #EBookBackend
+ * @db: DB handle
  *
  * Flags @cache as being populated - that is, it is up-to-date on the
  * contents of the book it's caching.
