@@ -89,14 +89,16 @@ add_contacts (EBookBackendSqliteDB *ebsdb)
 }
 
 static void
-search_db (EBookBackendSqliteDB *ebsdb, const gchar *type, const gchar *sexp)
+search_db (EBookBackendSqliteDB *ebsdb,
+           const gchar *type,
+           const gchar *sexp)
 {
 	GSList *vcards;
 	EbSdbSearchData *s_data;
 
 	g_print ("%s - query: %s \n", type, sexp);
 	op = type;
-	vcards = e_book_backend_sqlitedb_search (ebsdb, folderid, sexp, NULL, &error);
+	vcards = e_book_backend_sqlitedb_search (ebsdb, folderid, sexp, NULL, NULL, NULL, &error);
 	if (error)
 		return;
 
@@ -113,13 +115,12 @@ start_tests (gpointer data)
 	gchar *vcard_str = NULL, *sexp;
 	EBookQuery *q;
 	GSList *uids = NULL;
-	gboolean store_vcard = FALSE;
 
 	g_print ("Creating the sqlitedb \n");
 	op = "create sqlitedb";
 	ebsdb = e_book_backend_sqlitedb_new
 					(cache_path, email, folderid, folder_name,
-					 store_vcard, &error);
+					 FALSE, &error);
 	if (error)
 		goto exit;
 
@@ -148,7 +149,7 @@ start_tests (gpointer data)
 
 	g_print ("Get Vcard string \n");
 	op = "get vcard string";
-	vcard_str = e_book_backend_sqlitedb_get_vcard_string (ebsdb, folderid, uid, &error);
+	vcard_str = e_book_backend_sqlitedb_get_vcard_string (ebsdb, folderid, uid, NULL, NULL, &error);
 	if (error)
 		goto exit;
 	g_print ("VCard: %s \n", vcard_str);
@@ -162,7 +163,7 @@ start_tests (gpointer data)
 	if (error)
 		goto exit;
 
-	if (store_vcard) {
+	/* if (store_vcard) {
 		q = e_book_query_any_field_contains ("word");
 		sexp = e_book_query_to_string (q);
 		search_db (ebsdb, "full_search query", sexp);
@@ -170,7 +171,7 @@ start_tests (gpointer data)
 		g_free (sexp);
 		if (error)
 			goto exit;
-	}
+	} */
 
 	g_print ("Delete contact \n");
 	op = "delete contact";
@@ -191,10 +192,10 @@ exit:
 }
 
 gint
-main (gint argc, gchar *argv[])
+main (gint argc,
+      gchar *argv[])
 {
 	g_type_init ();
-	g_thread_init (NULL);
 
 	if (argc != 2) {
 		g_print ("Please enter a path to store the cache \n");
