@@ -1320,6 +1320,9 @@ init_sources_cb (ECalBackendContacts *cbc)
 
 	priv = cbc->priv;
 
+	if (!priv->addressbook_sources)
+		return NULL;
+
 	/* Create address books for existing sources */
 	for (i = e_source_list_peek_groups (priv->addressbook_sources); i; i = i->next) {
 		ESourceGroup *source_group = E_SOURCE_GROUP (i->data);
@@ -1508,7 +1511,8 @@ e_cal_backend_contacts_finalize (GObject *object)
 		priv->update_alarms_id = 0;
 	}
 
-	g_object_unref (priv->addressbook_sources);
+	if (priv->addressbook_sources)
+		g_object_unref (priv->addressbook_sources);
 	g_hash_table_destroy (priv->addressbooks);
 	g_hash_table_destroy (priv->credentials);
 	g_hash_table_destroy (priv->tracked_contacts);
@@ -1537,7 +1541,8 @@ e_cal_backend_contacts_init (ECalBackendContacts *cbc)
 
 	priv = g_new0 (ECalBackendContactsPrivate, 1);
 
-	e_book_client_get_sources (&priv->addressbook_sources, NULL);
+	if (!e_book_client_get_sources (&priv->addressbook_sources, NULL))
+		priv->addressbook_sources = NULL;
 
 	priv->addressbooks = g_hash_table_new_full (g_str_hash, g_str_equal,
 						    g_free, (GDestroyNotify) book_record_free);
