@@ -34,8 +34,6 @@
 
 #include <glib/gstdio.h>
 
-#include <libedataserver/e-memory.h>
-
 #include "camel-certdb.h"
 #include "camel-file-utils.h"
 #include "camel-win32.h"
@@ -79,7 +77,7 @@ certdb_finalize (GObject *object)
 	g_free (certdb->filename);
 
 	if (certdb->cert_chunks)
-		e_memchunk_destroy (certdb->cert_chunks);
+		camel_memchunk_destroy (certdb->cert_chunks);
 
 	g_mutex_free (priv->db_lock);
 	g_mutex_free (priv->io_lock);
@@ -221,6 +219,10 @@ certdb_cert_load (CamelCertDB *certdb,
 	if (camel_file_util_decode_uint32 (istream, &cert->trust) == -1)
 		goto error;
 
+	/* unset temporary trusts on load */
+	if (cert->trust == CAMEL_CERT_TRUST_TEMPORARY)
+		cert->trust = CAMEL_CERT_TRUST_UNKNOWN;
+
 	return cert;
 
  error:
@@ -246,6 +248,10 @@ camel_certdb_load (CamelCertDB *certdb)
 		return -1;
 
 	class = CAMEL_CERTDB_GET_CLASS (certdb);
+	if (!class->header_load || !class->cert_load) {
+		fclose (in);
+		in = NULL;
+	}
 	g_return_val_if_fail (class->header_load != NULL, -1);
 	g_return_val_if_fail (class->cert_load != NULL, -1);
 
@@ -346,6 +352,10 @@ camel_certdb_save (CamelCertDB *certdb)
 	}
 
 	class = CAMEL_CERTDB_GET_CLASS (certdb);
+	if (!class->header_save || !class->cert_save) {
+		fclose (out);
+		out = NULL;
+	}
 	g_return_val_if_fail (class->header_save != NULL, -1);
 	g_return_val_if_fail (class->cert_save != NULL, -1);
 
@@ -478,7 +488,7 @@ certdb_cert_new (CamelCertDB *certdb)
 	CamelCert *cert;
 
 	if (certdb->cert_chunks)
-		cert = e_memchunk_alloc0 (certdb->cert_chunks);
+		cert = camel_memchunk_alloc0 (certdb->cert_chunks);
 	else
 		cert = g_malloc0 (certdb->cert_size);
 
@@ -548,7 +558,7 @@ camel_certdb_cert_unref (CamelCertDB *certdb,
 	if (cert->refcount <= 1) {
 		class->cert_free (certdb, cert);
 		if (certdb->cert_chunks)
-			e_memchunk_free (certdb->cert_chunks, cert);
+			camel_memchunk_free (certdb->cert_chunks, cert);
 		else
 			g_free (cert);
 	} else {
