@@ -428,6 +428,7 @@ report_status (CamelFilterDriver *driver,
 	if (driver->priv->statusfunc) {
 		va_start (ap, desc);
 		str = g_strdup_vprintf (desc, ap);
+		va_end (ap);
 		driver->priv->statusfunc (driver, status, pc, str, driver->priv->statusdata);
 		g_free (str);
 	}
@@ -694,11 +695,16 @@ do_color (struct _CamelSExp *f,
 
 	d(fprintf (stderr, "setting color tag\n"));
 	if (argc > 0 && argv[0]->type == CAMEL_SEXP_RES_STRING) {
+		const gchar *color = argv[0]->value.string;
+
+		if (color && !*color)
+			color = NULL;
+
 		if (p->source && p->uid && camel_folder_has_summary_capability (p->source))
-			camel_folder_set_message_user_tag (p->source, p->uid, "color", argv[0]->value.string);
+			camel_folder_set_message_user_tag (p->source, p->uid, "color", color);
 		else
-			camel_message_info_set_user_tag(p->info, "color", argv[0]->value.string);
-		camel_filter_driver_log (driver, FILTER_LOG_ACTION, "Set color to %s", argv[0]->value.string);
+			camel_message_info_set_user_tag(p->info, "color", color);
+		camel_filter_driver_log (driver, FILTER_LOG_ACTION, "Set color to %s", color ? color : "None");
 	}
 
 	return NULL;
@@ -1179,6 +1185,7 @@ camel_filter_driver_log (CamelFilterDriver *driver,
 
 			va_start (ap, desc);
 			str = g_strdup_vprintf (desc, ap);
+			va_end (ap);
 		}
 
 		switch (status) {
@@ -1350,7 +1357,8 @@ camel_filter_driver_filter_mbox (CamelFilterDriver *driver,
 		goto fail;
 	}
 	/* to get the filesize */
-	fstat (fd, &st);
+	if (fstat (fd, &st) != 0)
+		st.st_size = 0;
 
 	mp = camel_mime_parser_new ();
 	camel_mime_parser_scan_from (mp, TRUE);
@@ -1515,8 +1523,9 @@ camel_filter_driver_filter_folder (CamelFilterDriver *driver,
 				CAMEL_MESSAGE_DELETED |
 				CAMEL_MESSAGE_SEEN, ~0);
 
-		camel_uid_cache_save_uid (cache, uids->pdata[i]);
-		if (cache && i%10 == 0)
+		if (cache)
+			camel_uid_cache_save_uid (cache, uids->pdata[i]);
+		if (cache && (i % 10) == 0)
 			camel_uid_cache_save (cache);
 	}
 
