@@ -153,11 +153,11 @@ write_references (CamelStream *stream,
 
 	while (*value) {
 		ids = value;
-		ide = strchr (ids+1, '>');
+		ide = strchr (ids + 1, '>');
 		if (ide)
 			value = ++ide;
 		else
-			ide = value = strlen (ids)+ids;
+			ide = value = strlen (ids) + ids;
 
 		if (len > 0 && len + (ide - ids) >= CAMEL_FOLD_SIZE) {
 			g_string_append_len (buffer, "\n\t", 2);
@@ -184,6 +184,9 @@ write_references (CamelStream *stream,
 static void
 init_header_name_table (void)
 {
+	if (header_name_table)
+		return;
+
 	header_name_table = g_hash_table_new (
 		camel_strcase_hash, camel_strcase_equal);
 	g_hash_table_insert (
@@ -542,7 +545,7 @@ mime_part_write_to_stream_sync (CamelDataWrapper *dw,
 						 GError **error);
 
 		/* fold/write the headers.   But dont fold headers that are already formatted
-		   (e.g. ones with parameter-lists, that we know about, and have created) */
+		 * (e.g. ones with parameter-lists, that we know about, and have created) */
 		while (h) {
 			val = h->value;
 			if (val == NULL) {
@@ -592,6 +595,8 @@ mime_part_write_to_stream_sync (CamelDataWrapper *dw,
 		}
 
 		if (mp->priv->encoding != content->encoding) {
+			gchar *content;
+
 			switch (mp->priv->encoding) {
 			case CAMEL_TRANSFER_ENCODING_BASE64:
 				filter = camel_mime_filter_basic_new (CAMEL_MIME_FILTER_BASIC_BASE64_ENC);
@@ -601,16 +606,18 @@ mime_part_write_to_stream_sync (CamelDataWrapper *dw,
 				break;
 			case CAMEL_TRANSFER_ENCODING_UUENCODE:
 				filename = camel_mime_part_get_filename (mp);
-				count = camel_stream_printf (
-					ostream, "begin 644 %s\n",
-					filename ? filename : "untitled");
-				if (count == -1) {
-					g_set_error (
-						error, G_IO_ERROR,
-						g_io_error_from_errno (errno),
-						"%s", g_strerror (errno));
+				if (filename == NULL)
+					filename = "untitled";
+
+				content = g_strdup_printf (
+					"begin 644 %s\n", filename);
+				count = camel_stream_write_string (
+					ostream, content, cancellable, error);
+				g_free (content);
+
+				if (count == -1)
 					return -1;
-				}
+
 				total += count;
 				filter = camel_mime_filter_basic_new (CAMEL_MIME_FILTER_BASIC_UU_ENC);
 				break;
@@ -784,10 +791,8 @@ mime_part_construct_from_parser_thread (GSimpleAsyncResult *simple,
 		CAMEL_MIME_PART (object), async_context->parser,
 		cancellable, &error);
 
-	if (error != NULL) {
-		g_simple_async_result_set_from_error (simple, error);
-		g_error_free (error);
-	}
+	if (error != NULL)
+		g_simple_async_result_take_error (simple, error);
 }
 
 static void
@@ -981,7 +986,7 @@ camel_mime_part_set_content (CamelMimePart *mime_part,
  * @mime_part: a #CamelMimePart
  *
  * Get the disposition of the MIME part as a structure.
- * Returned pointer is owned by #mime_part.
+ * Returned pointer is owned by @mime_part.
  *
  * Returns: the disposition structure
  *
