@@ -148,7 +148,7 @@ soundexify (const gchar *sound,
 
 	for (c = (guchar *) sound; *c && !isalpha (*c); c++);
 	code[0] = toupper (*c);
-	memset (code + 1, '0', 3);
+	memset (code + 1, 0, 3);
 	for (n = 1; *c && n < 5; c++) {
 		guchar ch = soundex_table[*c];
 
@@ -211,7 +211,8 @@ camel_ustrstrcase (const gchar *haystack,
 	if (strlen (haystack) == 0)
 		return NULL;
 
-	puni = nuni = g_alloca (sizeof (gunichar) * strlen (needle));
+	puni = nuni = g_alloca (sizeof (gunichar) * (strlen (needle) + 1));
+	nuni[0] = 0;
 
 	p = (const guchar *) needle;
 	while ((u = camel_utf8_getc (&p)))
@@ -294,6 +295,65 @@ camel_ustrcasecmp (const gchar *ps1,
 	return 0;
 }
 
+static gchar *
+depunct_string (const gchar *str)
+{
+	gchar *res;
+	gint ii;
+
+	g_return_val_if_fail (str != NULL, NULL);
+
+	res = g_strdup (str);
+	for (ii = 0; res[ii]; ii++) {
+		if (ispunct (res[ii]))
+			res[ii] = ' ';
+	}
+
+	return res;
+}
+
+static gboolean
+camel_uwordcase (const gchar *haystack,
+		 const gchar *needle)
+{
+	struct _camel_search_words *hwords, *nwords;
+	gchar *copy_haystack, *copy_needle;
+	gboolean found_all;
+	gint ii, jj;
+
+	g_return_val_if_fail (haystack != NULL, FALSE);
+	g_return_val_if_fail (needle != NULL, FALSE);
+
+	if (!*needle)
+		return TRUE;
+	if (!*haystack)
+		return FALSE;
+
+	copy_haystack = depunct_string (haystack);
+	copy_needle = depunct_string (needle);
+	hwords = camel_search_words_split ((const guchar *) copy_haystack);
+	nwords = camel_search_words_split ((const guchar *) copy_needle);
+	g_free (copy_haystack);
+	g_free (copy_needle);
+
+	found_all = TRUE;
+	for (ii = 0; ii < nwords->len && found_all; ii++) {
+		found_all = FALSE;
+
+		for (jj = 0; jj < hwords->len; jj++) {
+			if (camel_ustrcasecmp (hwords->words[jj]->word, nwords->words[ii]->word) == 0) {
+				found_all = TRUE;
+				break;
+			}
+		}
+	}
+
+	camel_search_words_free (hwords);
+	camel_search_words_free (nwords);
+
+	return found_all;
+}
+
 static gint
 camel_ustrncasecmp (const gchar *ps1,
                     const gchar *ps2,
@@ -338,9 +398,7 @@ header_match (const gchar *value,
               const gchar *match,
               camel_search_match_t how)
 {
-	const guchar *p;
 	gint vlen, mlen;
-	gunichar c;
 
 	if (how == CAMEL_SEARCH_MATCH_SOUNDEX)
 		return header_soundex (value, match);
@@ -350,32 +408,13 @@ header_match (const gchar *value,
 	if (vlen < mlen)
 		return FALSE;
 
-	/* from dan the man, if we have mixed case, perform a case-sensitive match,
-	 * otherwise not */
-	p = (const guchar *) match;
-	while ((c = camel_utf8_getc (&p))) {
-		if (g_unichar_isupper (c)) {
-			switch (how) {
-			case CAMEL_SEARCH_MATCH_EXACT:
-				return strcmp (value, match) == 0;
-			case CAMEL_SEARCH_MATCH_CONTAINS:
-				return strstr (value, match) != NULL;
-			case CAMEL_SEARCH_MATCH_STARTS:
-				return strncmp (value, match, mlen) == 0;
-			case CAMEL_SEARCH_MATCH_ENDS:
-				return strcmp (value + vlen - mlen, match) == 0;
-			default:
-				break;
-			}
-			return FALSE;
-		}
-	}
-
 	switch (how) {
 	case CAMEL_SEARCH_MATCH_EXACT:
 		return camel_ustrcasecmp (value, match) == 0;
 	case CAMEL_SEARCH_MATCH_CONTAINS:
 		return camel_ustrstrcase (value, match) != NULL;
+	case CAMEL_SEARCH_MATCH_WORD:
+		return camel_uwordcase (value, match);
 	case CAMEL_SEARCH_MATCH_STARTS:
 		return camel_ustrncasecmp (value, match, mlen) == 0;
 	case CAMEL_SEARCH_MATCH_ENDS:
