@@ -47,6 +47,7 @@ static gboolean imap_command_start (CamelImapStore *store, CamelFolder *folder,
 				    const gchar *cmd, GCancellable *cancellable,
 				    GError **error);
 static CamelImapResponse *imap_read_response (CamelImapStore *store,
+					      CamelFolder *folder,
 					      GCancellable *cancellable,
 					      GError **error);
 static gchar *imap_read_untagged (CamelImapStore *store, gchar *line,
@@ -119,7 +120,7 @@ camel_imap_command (CamelImapStore *store,
 	}
 	g_free (cmd);
 
-	return imap_read_response (store, cancellable, error);
+	return imap_read_response (store, folder, cancellable, error);
 }
 
 /**
@@ -264,6 +265,7 @@ imap_command_start (CamelImapStore *store,
 /**
  * camel_imap_command_continuation:
  * @store: the IMAP store
+ * @folder: a #CamelFolder on which the command was run; can be %NULL
  * @cmd: buffer containing the response/request data
  * @cmdlen: command length
  * @error: return location for a #GError, or %NULL
@@ -279,6 +281,7 @@ imap_command_start (CamelImapStore *store,
  **/
 CamelImapResponse *
 camel_imap_command_continuation (CamelImapStore *store,
+				 CamelFolder *folder,
                                  const gchar *cmd,
                                  gsize cmdlen,
                                  GCancellable *cancellable,
@@ -311,12 +314,13 @@ camel_imap_command_continuation (CamelImapStore *store,
 		return NULL;
 	}
 
-	return imap_read_response (store, cancellable, error);
+	return imap_read_response (store, folder, cancellable, error);
 }
 
 /**
  * camel_imap_command_response:
  * @store: the IMAP store
+ * @folder: a #CamelFolder on which the command was run; can be %NULL
  * @response: a pointer to pass back the response data in
  * @cancellable: optional #GCancellable object, or %NULL
  * @error: return location for a #GError, or %NULL
@@ -332,6 +336,7 @@ camel_imap_command_continuation (CamelImapStore *store,
  **/
 CamelImapResponseType
 camel_imap_command_response (CamelImapStore *store,
+			     CamelFolder *folder,
                              gchar **response,
                              GCancellable *cancellable,
                              GError **error)
@@ -341,21 +346,22 @@ camel_imap_command_response (CamelImapStore *store,
 	CamelService *service;
 	CamelSession *session;
 	CamelImapResponseType type;
-	const gchar *host;
-	const gchar *user;
 	gchar *respbuf;
+	gchar *host;
+	gchar *user;
 
 	service = CAMEL_SERVICE (store);
 	session = camel_service_get_session (service);
 	settings = camel_service_get_settings (service);
 
 	network_settings = CAMEL_NETWORK_SETTINGS (settings);
-	host = camel_network_settings_get_host (network_settings);
-	user = camel_network_settings_get_user (network_settings);
+	host = camel_network_settings_dup_host (network_settings);
+	user = camel_network_settings_dup_user (network_settings);
 
 	if (camel_imap_store_readline (store, &respbuf, cancellable, error) < 0) {
 		g_static_rec_mutex_unlock (&store->command_and_response_lock);
-		return CAMEL_IMAP_RESPONSE_ERROR;
+		type = CAMEL_IMAP_RESPONSE_ERROR;
+		goto exit;
 	}
 
 	switch (*respbuf) {
@@ -388,21 +394,36 @@ camel_imap_command_response (CamelImapStore *store,
 			store, respbuf, cancellable, error);
 		if (!respbuf)
 			type = CAMEL_IMAP_RESPONSE_ERROR;
-		else if (!g_ascii_strncasecmp (respbuf, "* OK [ALERT]", 12)
-			 || !g_ascii_strncasecmp (respbuf, "* NO [ALERT]", 12)
-			 || !g_ascii_strncasecmp (respbuf, "* BAD [ALERT]", 13)) {
-			gchar *msg;
+		else {
+			gboolean ok_alert = g_ascii_strncasecmp (respbuf, "* OK [ALERT]", 12) == 0;
+			gboolean bad_alert = g_ascii_strncasecmp (respbuf, "* BAD [ALERT]", 13) == 0;
 
-			/* for imap ALERT codes, account user@host */
-			/* we might get a ']' from a BAD response since we +12,
-			 * but who cares? */
-			msg = g_strdup_printf (
-				_("Alert from IMAP server %s@%s:\n%s"),
-				user, host, respbuf + 12);
-			camel_session_alert_user (
-				session, CAMEL_SESSION_ALERT_WARNING,
-				msg, FALSE);
-			g_free (msg);
+			if (ok_alert || bad_alert || g_ascii_strncasecmp (respbuf, "* NO [ALERT]", 12) == 0) {
+				const gchar *alert;
+				gchar *msg;
+
+				alert = respbuf + 12 + (bad_alert ? 1 : 0);
+
+				if (ok_alert) {
+					if (g_hash_table_lookup (store->known_alerts, alert))
+						break;
+
+					g_hash_table_insert (store->known_alerts, g_strdup (alert), GINT_TO_POINTER (1));
+				}
+
+				if (folder)
+					msg = g_strdup_printf (
+						_("Alert from IMAP server %s@%s in folder %s:\n%s"),
+						user, host, camel_folder_get_full_name (folder), alert);
+				else
+					msg = g_strdup_printf (
+						_("Alert from IMAP server %s@%s:\n%s"),
+						user, host, alert);
+				camel_session_alert_user (
+					session, CAMEL_SESSION_ALERT_WARNING,
+					msg, NULL);
+				g_free (msg);
+			}
 		}
 
 		break;
@@ -419,11 +440,16 @@ camel_imap_command_response (CamelImapStore *store,
 	    type == CAMEL_IMAP_RESPONSE_TAGGED)
 		g_static_rec_mutex_unlock (&store->command_and_response_lock);
 
+exit:
+	g_free (host);
+	g_free (user);
+
 	return type;
 }
 
 static CamelImapResponse *
 imap_read_response (CamelImapStore *store,
+		    CamelFolder *folder,
                     GCancellable *cancellable,
                     GError **error)
 {
@@ -446,7 +472,7 @@ imap_read_response (CamelImapStore *store,
 
 	response->untagged = g_ptr_array_new ();
 	while ((type = camel_imap_command_response (
-		store, &respbuf, cancellable, error))
+		store, folder, &respbuf, cancellable, error))
 		== CAMEL_IMAP_RESPONSE_UNTAGGED)
 		g_ptr_array_add (response->untagged, respbuf);
 
