@@ -54,8 +54,8 @@ maildir_folder_cmp_uids (CamelFolder *folder,
 	g_return_val_if_fail (folder != NULL, 0);
 	g_return_val_if_fail (folder->summary != NULL, 0);
 
-	a = camel_folder_summary_uid (folder->summary, uid1);
-	b = camel_folder_summary_uid (folder->summary, uid2);
+	a = camel_folder_summary_get (folder->summary, uid1);
+	b = camel_folder_summary_get (folder->summary, uid2);
 
 	g_return_val_if_fail (a != NULL, 0);
 	g_return_val_if_fail (b != NULL, 0);
@@ -94,7 +94,7 @@ maildir_folder_get_filename (CamelFolder *folder,
 	gchar *res;
 
 	/* get the message summary info */
-	if ((info = camel_folder_summary_uid (folder->summary, uid)) == NULL) {
+	if ((info = camel_folder_summary_get (folder->summary, uid)) == NULL) {
 		set_cannot_get_message_ex (
 			error, CAMEL_FOLDER_ERROR_INVALID_UID,
 			uid, lf->folder_path, _("No such message"));
@@ -158,12 +158,12 @@ maildir_folder_append_message_sync (CamelFolder *folder,
 	CamelMessageInfo *mi;
 	CamelMaildirMessageInfo *mdi;
 	gchar *name, *dest = NULL;
-	gboolean success = TRUE;
+	gboolean success = TRUE, has_attachment;
 
 	d(printf("Appending message\n"));
 
 	/* If we can't lock, don't do anything */
-	if (camel_local_folder_lock (lf, CAMEL_LOCK_WRITE, error) == -1)
+	if (!lf || camel_local_folder_lock (lf, CAMEL_LOCK_WRITE, error) == -1)
 		return FALSE;
 
 	/* add it to the summary/assign the uid, etc */
@@ -173,8 +173,11 @@ maildir_folder_append_message_sync (CamelFolder *folder,
 	if (mi == NULL)
 		goto check_changed;
 
-	if ((camel_message_info_flags (mi) & CAMEL_MESSAGE_ATTACHMENTS) && !camel_mime_message_has_attachment (message))
-		camel_message_info_set_flags (mi, CAMEL_MESSAGE_ATTACHMENTS, 0);
+	has_attachment = camel_mime_message_has_attachment (message);
+	if (((camel_message_info_flags (mi) & CAMEL_MESSAGE_ATTACHMENTS) && !has_attachment) ||
+	    ((camel_message_info_flags (mi) & CAMEL_MESSAGE_ATTACHMENTS) == 0 && has_attachment)) {
+		camel_message_info_set_flags (mi, CAMEL_MESSAGE_ATTACHMENTS, has_attachment ? CAMEL_MESSAGE_ATTACHMENTS : 0);
+	}
 
 	mdi = (CamelMaildirMessageInfo *) mi;
 
@@ -236,7 +239,7 @@ maildir_folder_append_message_sync (CamelFolder *folder,
  check_changed:
 	camel_local_folder_unlock (lf);
 
-	if (lf && camel_folder_change_info_changed (lf->changes)) {
+	if (camel_folder_change_info_changed (lf->changes)) {
 		camel_folder_changed (folder, lf->changes);
 		camel_folder_change_info_clear (lf->changes);
 	}
@@ -257,7 +260,7 @@ maildir_folder_get_message_sync (CamelFolder *folder,
 
 	d(printf("getting message: %s\n", uid));
 
-	if (camel_local_folder_lock (lf, CAMEL_LOCK_WRITE, error) == -1)
+	if (!lf || camel_local_folder_lock (lf, CAMEL_LOCK_WRITE, error) == -1)
 		return NULL;
 
 	name = maildir_folder_get_filename (folder, uid, error);
@@ -327,7 +330,7 @@ maildir_folder_transfer_messages_to_sync (CamelFolder *source,
 			CamelMaildirMessageInfo *mdi;
 			CamelMessageInfo *info;
 
-			if ((info = camel_folder_summary_uid (source->summary, uid)) == NULL) {
+			if ((info = camel_folder_summary_get (source->summary, uid)) == NULL) {
 				set_cannot_get_message_ex (
 					error, CAMEL_FOLDER_ERROR_INVALID_UID,
 					uid, lf->folder_path, _("No such message"));
@@ -419,12 +422,11 @@ maildir_folder_transfer_messages_to_sync (CamelFolder *source,
 
 static CamelLocalSummary *
 maildir_folder_create_summary (CamelLocalFolder *lf,
-                               const gchar *path,
                                const gchar *folder,
                                CamelIndex *index)
 {
 	return (CamelLocalSummary *) camel_maildir_summary_new (
-		CAMEL_FOLDER (lf), path, folder, index);
+		CAMEL_FOLDER (lf), folder, index);
 }
 
 static void
