@@ -1390,6 +1390,9 @@ user_delete_text (ENameSelectorEntry *name_selector_entry,
 	text = gtk_entry_get_text (GTK_ENTRY (name_selector_entry));
 	len = g_utf8_strlen (text, -1);
 
+	if (end_pos == -1)
+		end_pos = len;
+
 	gtk_editable_get_selection_bounds (
 		GTK_EDITABLE (name_selector_entry),
 		&selection_start, &selection_end);
@@ -2431,7 +2434,7 @@ editor_closed_cb (GtkWidget *editor,
 	if (book_client) {
 		contact = NULL;
 
-		e_book_client_get_contact_sync (book_client, contact_uid, &contact, NULL, NULL);
+		g_warn_if_fail (e_book_client_get_contact_sync (book_client, contact_uid, &contact, NULL, NULL));
 		email_num = e_destination_get_email_num (destination);
 		e_destination_set_contact (destination, contact, email_num);
 		e_destination_set_client (destination, book_client);
